# Setting up genomic intervals

```{eval-rst}
.. autoclass:: fwdpy11.Region
```

```{eval-rst}
.. autoclass:: fwdpy11.Sregion

    This class is an ABC derived from :class:`fwdpy11.Region`
```

```{eval-rst}
.. autoclass:: fwdpy11.ConstantS
```

```{eval-rst}
.. autoclass:: fwdpy11.UniformS
```

```{eval-rst}
.. autoclass:: fwdpy11.ExpS
```

```{eval-rst}
.. autoclass:: fwdpy11.GammaS
```

```{eval-rst}
.. autoclass:: fwdpy11.GaussianS
```

```{eval-rst}
.. autoclass:: fwdpy11.MultivariateGaussianEffects
```

```{eval-rst}
.. autoclass:: fwdpy11.LogNormalS

    .. automethod:: mv
```

```{eval-rst}
.. autoclass:: fwdpy11.DiscreteDESD
```

```{eval-rst}
.. autoclass:: fwdpy11.mvDES
```


```{eval-rst}
.. autoclass:: fwdpy11.PoissonInterval

```

```{eval-rst}
.. autoclass:: fwdpy11.PoissonPoint

```

```{eval-rst}
.. autoclass:: fwdpy11.BinomialPoint

```

```{eval-rst}
.. autoclass:: fwdpy11.FixedCrossovers

```

```{eval-rst}
.. autoclass:: fwdpy11.BinomialInterval

```

```{eval-rst}
.. autoclass:: fwdpy11.BinomialIntervalMap

```

```{eval-rst}
.. autoclass:: fwdpy11.MutationDominance
    
    See :ref:`here <mutationdominance_vignette>` for details.

.. autoclass:: fwdpy11.FixedDominance
    
    See :ref:`here <mutationdominance_vignette>` for details.

.. autoclass:: fwdpy11.UniformDominance
    
    See :ref:`here <mutationdominance_vignette>` for details.

.. autoclass:: fwdpy11.ExponentialDominance
    
    See :ref:`here <mutationdominance_vignette>` for details.

.. autoclass:: fwdpy11.LargeEffectExponentiallyRecessive
    
    See :ref:`here <mutationdominance_vignette>` for details.
```

